@@ -1,14 +1,13 @@
-# coding: utf-8
 
-# django imports
 from django.shortcuts import get_object_or_404
-from django.contrib.auth.models import User
 from django.conf import settings
 
+from mezzanine.utils.models import get_user_model
+
 
 def flash_login_required(function):
     """
-    Decorator to recognize a user  by its session.
+    Decorator to recognize a user by its session.
     Used for Flash-Uploading.
     """
 
@@ -21,6 +20,6 @@ def flash_login_required(function):
         session_data = engine.SessionStore(request.POST.get('session_key'))
         user_id = session_data['_auth_user_id']
         # will return 404 if the session ID does not resolve to a valid user
-        request.user = get_object_or_404(User, pk=user_id)
+        request.user = get_object_or_404(get_user_model(), pk=user_id)
         return function(request, *args, **kwargs)
     return decorator
